@@ -7,6 +7,7 @@ import tomllib
 import logging
 import warnings
 from collections import defaultdict
+import traceback
 
 from collections import Counter
 from datetime import datetime
@@ -106,6 +107,9 @@ class Biso:
     :cvar orientation: Orientation for plots ('v' for vertical, 'h' for horizontal).
     :cvar figure_file_extension: File extension of the figure (pdf, tex...).
     :cvar default_barcornerradius: Default corner radius for bars in plots.
+    :cvar default_dynamic_min_height: Default minimum height for plots when the height is set dynamically.
+    :cvar default_dynamic_height_per_bar: Default height per bar for plots when the height is set dynamically.
+    :cvar default_dynamic_bar_width: Default width for bars in plots when the height is set dynamically.
     :cvar default_hal_cursor_rows_per_request: Default number of rows per request when using the cursor API.
     :cvar default_height: Default height for plots.
     :cvar default_legend_pos: Default position for the legend.
@@ -124,6 +128,9 @@ class Biso:
     figure_file_extension = "pdf"
 
     default_barcornerradius = 10
+    default_dynamic_min_height = 150
+    default_dynamic_height_per_bar = 25
+    default_dynamic_bar_width = 0.7
     default_hal_cursor_rows_per_request = 10000
     default_height = 600
     default_language = "fr"
@@ -154,6 +161,9 @@ class Biso:
             lab,
             year: int | None = None,
             barcornerradius: int = default_barcornerradius,
+            dynamic_height: bool = True,
+            dynamic_min_height: int | float = default_dynamic_min_height,
+            dynamic_height_per_bar: int | float = default_dynamic_height_per_bar,
             height: int = default_height,
             language: str = default_language,
             legend_pos: dict = None,
@@ -184,6 +194,12 @@ class Biso:
         :type year: int | none, optional
         :param barcornerradius: Corner radius for bars in plots.
         :type barcornerradius: int, optional
+        :param dynamic_height: Whether to use dynamic height for the plot. Only implemented for horizontal bar plots.
+        :type dynamic_height: bool, optional
+        :param dynamic_min_height: Minimum height for the plot when the height is set dynamically.
+        :type dynamic_min_height: int | float, optional
+        :param dynamic_height_per_bar: Height per bar for plots when the height is set dynamically.
+        :type dynamic_height_per_bar: int | float, optional
         :param height: Height of the plot.
         :type height: int, optional
         :param language: Language for the plot. Default to 'fr'.
@@ -234,6 +250,9 @@ class Biso:
         else:
             self.year = year
         self.barcornerradius = barcornerradius
+        self.dynamic_height = dynamic_height
+        self.dynamic_min_height = dynamic_min_height
+        self.dynamic_height_per_bar = dynamic_height_per_bar
         self.height = height
         self.language = language
         if legend_pos is None:
@@ -266,10 +285,42 @@ class Biso:
         self.n_entities_found = None
         # self.max_entities_reached is set to True if the number of processed entities was limited by max_entities
         self.max_entities_reached = False
+        self.info = ""
 
         self._ = get_translator(language = self.language)
 
 
+    def generate_plot_info(
+            self,
+            hide_max_entities_reached_warning: bool = False,
+            hide_n_entities_warning: bool = False
+    ):
+        """
+        Generate the plot info.
+        This information is used to print a warning on the report.
+
+        :param hide_max_entities_reached_warning: If True, the warning about the maximum number of entities processed
+            is not displayed.
+        :type hide_max_entities_reached_warning: bool, optional
+        :param hide_n_entities_warning: If True, the warning about the number of entities found is not displayed.
+        :type hide_n_entities_warning: bool, optional
+        """
+        if self.max_entities_reached and not hide_max_entities_reached_warning:
+            self.info += r"\emoji{warning} "
+            self.info += self._("The data processing was limited by the maximum number of downloadable entities (")
+            self.info += str(self.max_entities)
+            self.info += self._("). Data can be missing or values can be lower than the real values. ")
+            self.info += r"\\"
+        if (self.n_entities_found is not None and self.n_entities_found > self.max_plotted_entities and
+                not hide_n_entities_warning):
+            self.info += self._("The number of displayed entities was limited to ")
+            self.info += str(self.max_plotted_entities)
+            self.info += self._(". In the API, ")
+            self.info += str(self.n_entities_found)
+            self.info += self._(" entities were found.")
+            self.info += r"\\"
+
+
     def get_no_data_plot(self) -> go.Figure:
         """Create the error plot."""
         return get_empty_plot_with_message(self._("No data"))
@@ -682,6 +733,15 @@ class Biso:
             x_values = list(self.data.values())
             y_values = list(self.data.keys())
 
+        if self.dynamic_height and self.orientation == 'h':
+            height = self.dynamic_height_per_bar*len(self.data.keys())
+            if height < self.dynamic_min_height:
+                height = self.dynamic_min_height
+            bar_width = self.default_dynamic_bar_width
+        else:
+            height = self.height
+            bar_width = get_bar_width(len(self.data.keys()))
+
         # Add a bar for each type
         fig.add_trace(go.Bar(
             x=x_values,
@@ -692,7 +752,7 @@ class Biso:
             textposition=self.text_position,
             textangle=0,
             cliponaxis=False,
-            width=get_bar_width(len(self.data.keys())),
+            width=bar_width,
         ))
 
         # Update layout for better visualization
@@ -700,7 +760,7 @@ class Biso:
             barmode='stack',
             barcornerradius=self.barcornerradius,
             width=self.width,
-            height=self.height,
+            height=height,
             template=self.template,
             legend=self.legend_pos,
             margin=self.margin,
@@ -744,23 +804,28 @@ class AnrProjects(Biso):
         and values are their respective counts.
         """
         try:
-            facet_url=(
-                f"https://api.archives-ouvertes.fr/search/{self.lab}/?q=publicationDateY_i:{self.year}"
-                f"&wt=json&rows=0&facet=true&facet.field=anrProjectAcronym_s&facet.limit={self.max_plotted_entities}"
+            facet_url = (
+                f"https://api.archives-ouvertes.fr/search/{self.lab}/?q=publicationDateY_i:{self.year}&wt=json&rows=0&"
+                f"facet=true&facet.field=anrProjectAcronym_s&facet.limit={self.max_plotted_entities}&facet.mincount=1&"
+                "stats=true&stats.field={!count=true+cardinality=true}anrProjectAcronym_s"
             )
-            facets=requests.get(facet_url).json()
-            anr_projects_list=facets.get('facet_counts', {}).get('facet_fields', {}).get('anrProjectAcronym_s', [])
-            self.data = {anr_projects_list[i]: anr_projects_list[i + 1] for i in range(0, len(anr_projects_list), 2)
-                         if anr_projects_list[i + 1] != 0}
+            res = requests.get(facet_url).json()
+            self.n_entities_found = (res.get('stats', {}).get('stats_fields', {}).get('anrProjectAcronym_s', {}).
+                                     get('cardinality', 0))
+            anr_projects_list = res.get('facet_counts', {}).get('facet_fields', {}).get('anrProjectAcronym_s', [])
+            self.data = {anr_projects_list[i]: anr_projects_list[i + 1] for i in range(0, len(anr_projects_list), 2)}
             if not self.data:
                 self.data_status = DataStatus.NO_DATA
             else:
                 self.data_status = DataStatus.OK
+            self.generate_plot_info()
+            return {"info": self.info}
         except Exception as e:
             print(f"Error fetching or formatting data: {e}")
+            traceback.print_exc()
             self.data = None
             self.data_status = DataStatus.ERROR
-            return
+            return {"info": self._("Error")}
 
 
 
@@ -795,7 +860,7 @@ class Chapters(Biso):
         book title (`bookTitle_s`), and publisher (`publisher_s`).
         """
         try:
-            url=(
+            url = (
                 f"https://api.archives-ouvertes.fr/search/{self.lab}/?q=*:*&fq=docType_s:COUV&"
                 f"fq=producedDateY_i:{self.year}&rows={self.max_plotted_entities}&wt=json&indent=true&"
                 f"fl=title_s,bookTitle_s,publisher_s"
@@ -826,11 +891,14 @@ class Chapters(Biso):
                     "publisher_s": self._("Publisher"),
                 })
                 self.data_status = DataStatus.OK
+            self.generate_plot_info()
+            return {"info": self.info}
         except Exception as e:
             print(f"Error fetching or formatting data: {e}")
+            traceback.print_exc()
             self.data = None
             self.data_status = DataStatus.ERROR
-            return
+            return {"info": self._("Error")}
 
 
     def get_figure(self) -> str:
@@ -850,7 +918,7 @@ class Chapters(Biso):
         latex_table = self.dataframe_to_longtable(
             self.data,
             alignments=['p{.4\\linewidth}','p{.35\\linewidth}','p{.15\\linewidth}'],
-            caption=self._("Chapters list"),
+            caption=self._("List of chapters entered in HAL"),
             label='tab_chapters',
             vertical_lines=False,
             max_plotted_entities=self.max_plotted_entities,
@@ -1060,10 +1128,12 @@ class CollaborationMap(Biso):
 
             print(f"{len(self.data)} unique institutions to plot")
 
+            self.generate_plot_info()
             stats = {
                 'collaborations_nb': collaborations_nb,
                 'institutions_nb': institutions_nb,
-                'countries_nb': countries_nb
+                'countries_nb': countries_nb,
+                'info': self.info
             }
 
             if collaborations_nb == 0:
@@ -1074,12 +1144,14 @@ class CollaborationMap(Biso):
             return stats
         except Exception as e:
             print(f"Error fetching or formatting data: {e}")
+            traceback.print_exc()
             self.data = None
             self.data_status = DataStatus.ERROR
             stats = {
                 'collaborations_nb': self._("Error"),
                 'institutions_nb': self._("Error"),
-                'countries_nb': self._("Error")
+                'countries_nb': self._("Error"),
+                'info': self._("Error")
             }
             return stats
 
@@ -1256,16 +1328,20 @@ class CollaborationNames(Biso):
 
         try:
             # Get count of each structure id in publications
-            structs_facet_url=(
+            structs_facet_url = (
                 f"https://api.archives-ouvertes.fr/search/{self.lab}/?q=publicationDateY_i:{self.year} AND "
                 f"docType_s:(ART OR COMM)&wt=json&rows=0&facet=true&facet.field=structId_i&"
-                f"facet.limit=10000"
+                f"facet.limit=10000&facet.mincount=1&stats=true&"
+                "stats.field={!count=true+cardinality=true}structId_i"
             )
-            structs_id_facets=requests.get(structs_facet_url).json()
-            structs_id_facets = structs_id_facets.get('facet_counts', {}).get('facet_fields', {}).get('structId_i', [])
+            res = requests.get(structs_facet_url).json()
+            self.n_entities_found = (res.get('stats', {}).get('stats_fields', {}).get('structId_i', {}).
+                                     get('cardinality', 0))
+            structs_id_facets = res.get('facet_counts', {}).get('facet_fields', {}).get('structId_i', [])
             if not structs_id_facets:
                 self.data_status = DataStatus.NO_DATA
-                return
+                self.generate_plot_info()
+                return {"info": self.info}
             structs_id_count = {
                 struct_id: count for struct_id, count in zip(structs_id_facets[::2], structs_id_facets[1::2])
             }
@@ -1296,7 +1372,8 @@ class CollaborationNames(Biso):
                 ]
             if not struct_list:
                 self.data_status = DataStatus.NO_DATA
-                return
+                self.generate_plot_info()
+                return {"info": self.info}
 
             self.data = {
                 format_structure_name(struct['label_s'], struct.get('country_s', None)):
@@ -1306,11 +1383,14 @@ class CollaborationNames(Biso):
             # sort values
             self.data = {k: v for k, v in sorted(self.data.items(), key=lambda item: item[1])}
             self.data_status = DataStatus.OK
+            self.generate_plot_info()
+            return {"info": self.info}
         except Exception as e:
             print(f"Error fetching or formatting data: {e}")
+            traceback.print_exc()
             self.data = None
             self.data_status = DataStatus.ERROR
-            return
+            return {"info": self._("Error")}
 
 
 class Conferences(Biso):
@@ -1369,13 +1449,20 @@ class Conferences(Biso):
             return conf_name
 
         try:
-            facet_url=(
+            stats_url = (
+                f"https://api.archives-ouvertes.fr/search/{self.lab}/?q=publicationDateY_i:{self.year} AND "
+                "docType_s:(COMM)&wt=json&rows=0&stats=true&stats.field={!count=true+cardinality=true}conferenceTitle_s"
+            )
+            res = requests.get(stats_url).json()
+            self.n_entities_found = (res.get('stats', {}).get('stats_fields', {}).get('conferenceTitle_s', {}).
+                                     get('cardinality', 0))
+            facet_url = (
                 f"https://api.archives-ouvertes.fr/search/{self.lab}/?q=publicationDateY_i:{self.year} AND "
                 f"docType_s:(COMM)&wt=json&rows=0&facet=true&facet.pivot=conferenceTitle_s,country_s&"
-                f"facet.limit={self.max_plotted_entities}"
+                f"facet.limit={self.max_plotted_entities}&facet.mincount=1"
             )
-            facets=requests.get(facet_url).json()
-            conferences_list = facets.get('facet_counts', {}).get('facet_pivot', {}).get(
+            res = requests.get(facet_url).json()
+            conferences_list = res.get('facet_counts', {}).get('facet_pivot', {}).get(
                 'conferenceTitle_s,country_s', [])
             if not conferences_list:
                 self.data_status = DataStatus.NO_DATA
@@ -1389,11 +1476,14 @@ class Conferences(Biso):
                     for conf in conferences_list
                 }
                 self.data_status = DataStatus.OK
+            self.generate_plot_info()
+            return {"info": self.info}
         except Exception as e:
             print(f"Error fetching or formatting data: {e}")
+            traceback.print_exc()
             self.data = None
             self.data_status = DataStatus.ERROR
-            return
+            return {"info": self._("Error")}
 
 class EuropeanProjects(Biso):
     """
@@ -1430,20 +1520,26 @@ class EuropeanProjects(Biso):
             facet_url=(
                 f"https://api.archives-ouvertes.fr/search/{self.lab}/?q=publicationDateY_i:{self.year}&wt=json&rows=0"
                 f"&facet=true&facet.field=europeanProjectAcronym_s&facet.limit={self.max_plotted_entities}"
+                "&facet.mincount=1&stats=true&stats.field={!count=true+cardinality=true}europeanProjectAcronym_s"
             )
-            facets=requests.get(facet_url).json()
-            eu_projects_list=facets.get('facet_counts', {}).get('facet_fields', {}).get('europeanProjectAcronym_s', [])
+            res = requests.get(facet_url).json()
+            self.n_entities_found = (res.get('stats', {}).get('stats_fields', {}).get('europeanProjectAcronym_s', {}).
+                                     get('cardinality', 0))
+            eu_projects_list=res.get('facet_counts', {}).get('facet_fields', {}).get('europeanProjectAcronym_s', [])
             self.data = {eu_projects_list[i]: eu_projects_list[i + 1] for i in range(0, len(eu_projects_list), 2)
                          if eu_projects_list[i + 1] != 0}
             if not self.data:
                 self.data_status = DataStatus.NO_DATA
             else:
                 self.data_status = DataStatus.OK
+            self.generate_plot_info()
+            return {"info": self.info}
         except Exception as e:
             print(f"Error fetching or formatting data: {e}")
+            traceback.print_exc()
             self.data = None
             self.data_status = DataStatus.ERROR
-            return
+            return {"info": self._("Error")}
 
 
 class Journals(Biso):
@@ -1511,7 +1607,9 @@ class Journals(Biso):
                 stats = {
                     'nb_works': self._("Error"),
                     'nb_works_found_in_bso': self._("Error"),
-                    'nb_journals': self._("Error")
+                    'nb_journals': self._("Error"),
+                    'bso_version': self.scanr_bso_version,
+                    'info': self._("Error")
                 }
                 return stats
             doi_ids = self.get_all_ids_with_cursor(id_type="doi")
@@ -1580,14 +1678,30 @@ class Journals(Biso):
                             warnings.warn(f"Unknown oa color {oa_colors[0]}")
 
 
-            self.data = pd.DataFrame.from_records(works)
+            self.data = pd.DataFrame.from_records(
+                works,
+                columns=[
+                    "journal_name",
+                    "publisher",
+                    "oa_colors",
+                    "oa_host_type",
+                    "paid_apc",
+                    "apc_paid_value",
+                    "apc_paid_currency",
+                    "is_oa_on_journal",
+                    "is_oa_on_repository",
+                ]
+            )
 
             if len(self.data.index) == 0:
                 self.data_status = DataStatus.NO_DATA
+                self.generate_plot_info()
                 stats = {
                     'nb_works': nb_works,
                     'nb_works_found_in_bso': nb_found_works,
-                    'nb_journals': 0
+                    'nb_journals': 0,
+                    'bso_version': self.scanr_bso_version,
+                    'info': self.info
                 }
                 return stats
 
@@ -1624,9 +1738,11 @@ class Journals(Biso):
             unspecified_journals_idx = self.data.index[
                 self.data["journal_name"] == self._("Unspecified journal")
             ].tolist()
-            idx.remove(unspecified_journals_idx[0])
-            # reindex the dataframe to move the Unspecified journal to the end
-            self.data = self.data.reindex(idx + unspecified_journals_idx)
+            # if Unspecified journal was found in the index
+            if unspecified_journals_idx:
+                idx.remove(unspecified_journals_idx[0])
+                # reindex the dataframe to move the Unspecified journal to the end
+                self.data = self.data.reindex(idx + unspecified_journals_idx)
             nb_journals = (self.data["journal_name"] != self._("Unspecified journal")).sum()
 
             if len(self.data.index) == 0:
@@ -1634,21 +1750,27 @@ class Journals(Biso):
             else:
                 self.data_status = DataStatus.OK
 
+            self.generate_plot_info()
             stats = {
                 'nb_works': nb_works,
                 'nb_works_found_in_bso': nb_found_works,
-                'nb_journals': int(nb_journals)
+                'nb_journals': int(nb_journals),
+                'bso_version': self.scanr_bso_version,
+                'info': self.info
             }
 
             return stats
         except Exception as e:
             print(f"Error fetching or formatting data: {e}")
+            traceback.print_exc()
             self.data = None
             self.data_status = DataStatus.ERROR
             stats = {
                 'nb_works': self._("Error"),
                 'nb_works_found_in_bso': self._("Error"),
-                'nb_journals': self._("Error")
+                'nb_journals': self._("Error"),
+                'bso_version': self.scanr_bso_version,
+                'info': self._("Error")
             }
             return stats
 
@@ -1719,24 +1841,32 @@ class JournalsHal(Biso):
         Fetch data about Journals from the HAL API.
         """
         try:
-            facet_url=(
+            facet_url = (
                 f"https://api.archives-ouvertes.fr/search/{self.lab}/?q=publicationDateY_i:{self.year}&wt=json&rows=0"
-                f"&facet=true&facet.field=journalTitle_s&facet.limit={self.max_plotted_entities}"
+                f"&facet=true&facet.field=journalTitle_s&facet.limit={self.max_plotted_entities}&facet.mincount=1&"
+                "stats=true&stats.field={!count=true+cardinality=true}journalTitle_s"
             )
-            facets=requests.get(facet_url).json()
-            jounals_list=facets.get('facet_counts', {}).get('facet_fields', {}).get('journalTitle_s', [])
-            self.data = {jounals_list[i]: jounals_list[i + 1] for i in range(0, len(jounals_list), 2)
-                         if jounals_list[i + 1] != 0}
+            res = requests.get(facet_url).json()
+            self.n_entities_found = (res.get('stats', {}).get('stats_fields', {}).get('journalTitle_s', {}).
+                                     get('cardinality', 0))
+            jounals_list=res.get('facet_counts', {}).get('facet_fields', {}).get('journalTitle_s', [])
+            self.data = {
+                jounals_list[i][:75]+"... " if len(jounals_list[i]) > 75 else jounals_list[i]: jounals_list[i + 1]
+                for i in range(0, len(jounals_list), 2)
+            }
             if not self.data:
                 self.data_status = DataStatus.NO_DATA
             else:
                 self.data = dict(sorted(self.data.items(), key=lambda item: item[1]))
                 self.data_status = DataStatus.OK
+            self.generate_plot_info()
+            return {"info": self.info}
         except Exception as e:
             print(f"Error fetching or formatting data: {e}")
+            traceback.print_exc()
             self.data = None
             self.data_status = DataStatus.ERROR
-            return
+            return {"info": self._("Error")}
 
 
 class OpenAccessWorks(Biso):
@@ -1810,39 +1940,39 @@ class OpenAccessWorks(Biso):
                 columns=['ti_dans_hal', 'oa_hors_hal', 'non_oa'],
                 index=range(self.year_range[0], self.year_range[1] + 1)
             )
-            facet_url=(
+            facet_url = (
                 f"https://api.archives-ouvertes.fr/search/{self.lab}/?q=publicationDateY_i:[{self.year_range[0]} TO "
                 f"{self.year_range[1]}] AND submitType_s:(file OR annex) AND docType_s:(ART OR COMM)&wt=json&"
                 f"rows=0&facet=true&facet.field=publicationDateY_i&facet.limit={self.max_plotted_entities}"
             )
-            facets=requests.get(facet_url).json()
-            ti_numbers=facets.get('facet_counts', {}).get('facet_fields', {}).get('publicationDateY_i', [])
+            facets = requests.get(facet_url).json()
+            ti_numbers = facets.get('facet_counts', {}).get('facet_fields', {}).get('publicationDateY_i', [])
             for ind, i in enumerate(ti_numbers):
                 if isinstance(i,str):
                     self.data.loc[int(i),'ti_dans_hal']=ti_numbers[ind+1]
                 else:
                     pass
 
-            oa_url=(
+            oa_url = (
                 f"https://api.archives-ouvertes.fr/search/{self.lab}/?q=publicationDateY_i:[{self.year_range[0]} TO "
                 f"{self.year_range[1]}] AND openAccess_bool:true AND submitType_s:notice AND docType_s:(ART OR COMM)&"
                 f"wt=json&rows=0&facet=true&facet.field=publicationDateY_i&facet.limit={self.max_plotted_entities}"
             )
-            oa=requests.get(oa_url).json()
-            oa_numbers=oa.get('facet_counts', {}).get('facet_fields', {}).get('publicationDateY_i', [])
+            oa = requests.get(oa_url).json()
+            oa_numbers = oa.get('facet_counts', {}).get('facet_fields', {}).get('publicationDateY_i', [])
             for ind, i in enumerate(oa_numbers):
                 if isinstance(i,str):
                     self.data.loc[int(i),'oa_hors_hal']=oa_numbers[ind+1]
                 else:
                     pass
 
-            non_oa_url=(
+            non_oa_url = (
                 f"https://api.archives-ouvertes.fr/search/{self.lab}/?q=publicationDateY_i:[{self.year_range[0]} TO "
                 f"{self.year_range[1]}] AND openAccess_bool:false AND submitType_s:notice  AND docType_s:(ART OR COMM)&"
                 f"wt=json&rows=0&facet=true&facet.field=publicationDateY_i&facet.limit={self.max_plotted_entities}"
             )
-            non_oa=requests.get(non_oa_url).json()
-            non_oa_numbers=non_oa.get('facet_counts', {}).get('facet_fields', {}).get('publicationDateY_i', [])
+            non_oa = requests.get(non_oa_url).json()
+            non_oa_numbers = non_oa.get('facet_counts', {}).get('facet_fields', {}).get('publicationDateY_i', [])
             for ind, i in enumerate(non_oa_numbers):
                 if isinstance(i,str):
                     self.data.loc[int(i),'non_oa']=int(non_oa_numbers[ind+1])
@@ -1854,16 +1984,20 @@ class OpenAccessWorks(Biso):
             else:
                 self.data_status = DataStatus.OK
 
+            self.generate_plot_info()
             stats = {
                 'oa_works_period': f"{self.year_range[0]} - {self.year_range[1]}",
+                'info': self.info
             }
             return stats
         except Exception as e:
             print(f"Error fetching or formatting data: {e}")
+            traceback.print_exc()
             self.data = None
             self.data_status = DataStatus.ERROR
             stats = {
                 'oa_works_period': f"{self.year_range[0]} - {self.year_range[1]}",
+                'info': self._("Error")
             }
             return stats
 
@@ -1988,7 +2122,7 @@ class PrivateSectorCollaborations(Biso):
         try:
             if self.scanr_api_url is None:
                 self.data_status = DataStatus.ERROR
-                return
+                return {"info": self._("Error")}
             doi_ids = self.get_all_ids_with_cursor(id_type="doi")
             hal_ids = self.get_all_ids_with_cursor(id_type="hal")
             # format IDs for scanr:
@@ -2017,6 +2151,8 @@ class PrivateSectorCollaborations(Biso):
                         # Extract the name (label) of the institution
                         if 'label' in affiliation:
                             name = affiliation['label'].get('default', affiliation['label'].get('fr', affiliation['label'].get('en', 'Unknown')))
+                            if len(name) > 75:
+                                name = name[:75]+"... "
                             collaborations[name] += 1
 
             self.data = dict(collaborations)
@@ -2026,11 +2162,15 @@ class PrivateSectorCollaborations(Biso):
             else:
                 self.data_status = DataStatus.OK
 
+            self.generate_plot_info()
+            return {"info": self.info}
+
         except Exception as e:
             print(f"Error fetching or formatting data: {e}")
+            traceback.print_exc()
             self.data = None
             self.data_status = DataStatus.ERROR
-            return
+            return {"info": self._("Error")}
 
 
 class WorksType(Biso):
@@ -2061,12 +2201,22 @@ class WorksType(Biso):
         counts.
         """
         try:
+            stats_url = (
+                f"https://api.archives-ouvertes.fr/search/{self.lab}/?q=publicationDateY_i:{self.year} AND "
+                "docType_s:(COMM)&wt=json&rows=0&stats=true&stats.field={!count=true+cardinality=true}docType_s"
+            )
+            res = requests.get(stats_url).json()
+            self.n_entities_found = (res.get('stats', {}).get('stats_fields', {}).get('docType_s', {}).
+                                     get('cardinality', 0))
             facet_url=(
                 f"https://api.archives-ouvertes.fr/search/{self.lab}/?q=publicationDateY_i:{self.year} &"
                 f"wt=json&rows=0&facet=true&facet.pivot=docType_s&facet.limit={self.max_plotted_entities}"
+                "&facet.mincount=1"
             )
-            facets=requests.get(facet_url).json()
-            document_types_list=facets.get('facet_counts', {}).get('facet_pivot', {}).get('docType_s', [])
+            res = requests.get(facet_url).json()
+            self.n_entities_found = (res.get('stats', {}).get('stats_fields', {}).get('docType_s', {}).
+                                     get('cardinality', 0))
+            document_types_list = res.get('facet_counts', {}).get('facet_pivot', {}).get('docType_s', [])
             if not document_types_list:
                 self.data_status = DataStatus.NO_DATA
             else:
@@ -2074,8 +2224,11 @@ class WorksType(Biso):
                     get_hal_doc_type_name(doc_type['value']): doc_type['count'] for doc_type in document_types_list
                 }
                 self.data_status = DataStatus.OK
+            self.generate_plot_info()
+            return {"info": self.info}
         except Exception as e:
             print(f"Error fetching or formatting data: {e}")
+            traceback.print_exc()
             self.data = None
             self.data_status = DataStatus.ERROR
-            return
+            return {"info": self._("Error")}
